Undertow component provides the feature of a web server without depending on Servlet.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-undertow</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| port | int | Listen port | 80 |
| host | String | Host address | 0.0.0.0 |
| ssl | boolean | Enable SSL/TLS | false |
| sslPort | int | SSL listen port | 443 |
| keystorePath | String | Path to keystore file | - |
| keystorePassword | String | Password for keystore | - |
Jetty component provides the feature of a web server based on Eclipse Jetty.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-jetty</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| port | int | Listen port | 80 |
| host | String | Host address | 0.0.0.0 |
| ssl | boolean | Enable SSL/TLS | false |
| sslPort | int | SSL listen port | 443 |
| keystorePath | String | Path to keystore file | - |
| keystorePassword | String | Password for keystore | - |
HikariCP component provides a high-performance JDBC connection pool.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-HikariCP</artifactId>
</dependency>
Properties are passed via OptionMap in the constructor.
| Name | Key in OptionMap | Description |
|---|---|---|
| jdbcUrl | uri | JDBC connection URL |
| username | username | Database username |
| password | password | Database password |
| autoCommit | autoCommit? | Enable auto-commit |
| connectionTimeout | connTimeout | Connection timeout in ms |
| idleTimeout | idleTimeout | Idle timeout in ms |
| maxPoolSize | maxPoolSize | Maximum pool size |
| minimumIdle | minIdle | Minimum idle connections |
Doma2 component provides the DAO-oriented database mapping framework.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-doma2</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| dialect | Dialect | SQL dialect | StandardDialect |
| naming | Naming | Naming convention | Naming.DEFAULT |
| useLocalTransaction | boolean | Enable local transactions | true |
| maxRows | int | Maximum result rows | 0 |
| fetchSize | int | Fetch size for queries | 0 |
| queryTimeout | int | Query timeout in seconds | 0 |
| batchSize | int | Batch size for operations | 0 |
jOOQ component provides a DSL context for building type-safe SQL queries.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-jooq</artifactId>
</dependency>
JPA component provides a base for JPA entity manager integration.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-jpa</artifactId>
</dependency>
| Name | Type | Description |
|---|---|---|
| name | String | JPA persistence unit name |
| jpaProperties | Map | JPA configuration properties |
EclipseLink component provides an EntityManagerProvider implementation using EclipseLink.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-eclipselink</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| sqlLogLevel | String | Logging level for SQL | FINE |
| managedClasses | List | Entity classes (via registerClass) | [] |
Flyway component provides automatic database migration on startup.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-flyway</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| locations | String[] | Migration script locations | - |
| table | String | Migration metadata table name | schema_version |
| cleanBeforeMigration | boolean | Clean database before migration | false |
Freemarker component provides a template engine for rendering HTML.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-freemarker</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| prefix | String | Template directory prefix | templates |
| suffix | String | Template file suffix | .ftl |
| encoding | String | File encoding | UTF-8 |
Thymeleaf component provides a template engine for rendering HTML.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-thymeleaf</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| prefix | String | Template directory prefix | templates/ |
| suffix | String | Template file suffix | .html |
| encoding | String | File encoding | UTF-8 |
Jackson component provides a bean converter using Jackson ObjectMapper.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-jackson</artifactId>
</dependency>
S2UtilBeans component provides a bean converter using S2 Util Beans.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-s2util-beans</artifactId>
</dependency>
Metrics component provides the feature of collecting application metrics using Dropwizard Metrics.
<dependency>
<groupId>net.unit8.enkan</groupId>
<artifactId>enkan-component-metrics</artifactId>
</dependency>
| Name | Type | Description | Default |
|---|---|---|---|
| metricName | String | Base metric name prefix | enkan |